@@ -30,42 +30,40 @@
 #include <config.h>
 
 #include "rcsid.h"
-RCSID (PKG_VER "$Id: su.c,v 1.30 2005/04/02 14:09:48 kloczek Exp $")
-#include <sys/types.h>
+RCSID (PKG_VER "$Id: su.c,v 1.39 2005/07/18 10:14:39 kloczek Exp $")
+#include <grp.h>
+#include <pwd.h>
+#include <signal.h>
 #include <stdio.h>
+#include <sys/types.h>
+#include "prototypes.h"
+#include "defines.h"
+#include "pwauth.h"
+#include "getdef.h"
 #ifdef USE_PAM
 #include "pam_defs.h"
+#endif
+/*
+ * Assorted #defines to control su's behavior
+ */
+/*
+ * Global variables
+ */
+/* not needed by sulog.c anymore */
+static char name[BUFSIZ];
+static char oldname[BUFSIZ];
+
+#ifdef USE_PAM
 static const struct pam_conv conv = {
 	misc_conv,
 	NULL
 };
 
 static pam_handle_t *pamh = NULL;
+static int caught = 0;
 #endif
 
-#include "prototypes.h"
-#include "defines.h"
-
-#include <grp.h>
-#include <signal.h>
-#include <pwd.h>
-#include "pwauth.h"
-#include "getdef.h"
-
-/*
- * Assorted #defines to control su's behavior
- */
-
-/*
- * Global variables
- */
-
-/* not needed by sulog.c anymore */
-static char name[BUFSIZ];
-static char oldname[BUFSIZ];
-
 static char *Prog;
-
 extern struct passwd pwent;
 
 /*
@@ -73,9 +71,8 @@ extern struct passwd pwent;
  */
 
 extern char **newenvp;
-extern size_t newenvc;
-
 extern char **environ;
+extern size_t newenvc;
 
 /* local function prototypes */
 
@@ -125,7 +122,7 @@ static void su_failure (const char *tty)
 #ifdef USE_SYSLOG
 	if (getdef_bool ("SYSLOG_SU_ENAB"))
 		SYSLOG ((pwent.pw_uid ? LOG_INFO : LOG_NOTICE,
-			 "- %s %s-%s", tty,
+			 "- %s %s:%s", tty,
 			 oldname[0] ? oldname : "???", name[0] ? name : "???"));
 	closelog ();
 #endif
@@ -133,9 +130,8 @@ static void su_failure (const char *tty)
 	exit (1);
 }
 
-#ifdef USE_PAM
-static int caught = 0;
 
+#ifdef USE_PAM
 /* Signal handler for parent process later */
 static void su_catch_sig (int sig)
 {
@@ -270,9 +266,8 @@ int main (int argc, char **argv)
 	RETSIGTYPE (*oldsig) ();
 	int is_console = 0;
 
-#ifdef	SHADOWPWD
 	struct spwd *spwd = 0;
-#endif
+
 #ifdef SU_ACCESS
 	char *oldpass;
 #endif
@@ -342,13 +337,6 @@ int main (int argc, char **argv)
 	 */
 
 	if (fakelogin) {
-		if ((cp = getdef_str ("ENV_TZ")))
-			addenv (*cp == '/' ? tz (cp) : cp, NULL);
-		/*
-		 * The clock frequency will be reset to the login value if required
-		 */
-		if ((cp = getdef_str ("ENV_HZ")))
-			addenv (cp, NULL);	/* set the default $HZ, if one */
 		/*
 		 * The terminal type will be left alone if it is present in
 		 * the environment already.
@@ -356,6 +344,13 @@ int main (int argc, char **argv)
 		if ((cp = getenv ("TERM")))
 			addenv ("TERM", cp);
 #ifndef USE_PAM
+		if ((cp = getdef_str ("ENV_TZ")))
+			addenv (*cp == '/' ? tz (cp) : cp, NULL);
+		/*
+		 * The clock frequency will be reset to the login value if required
+		 */
+		if ((cp = getdef_str ("ENV_HZ")))
+			addenv (cp, NULL);	/* set the default $HZ, if one */
 		/*
 		 * Also leave DISPLAY and XAUTHORITY if present, else
 		 * pam_xauth will not work.
@@ -405,10 +400,8 @@ int main (int argc, char **argv)
 	 * Sort out the password of user calling su, in case needed later
 	 * -- chris
 	 */
-#ifdef SHADOWPWD
 	if ((spwd = getspnam (oldname)))
 		pw->pw_passwd = spwd->sp_pwdp;
-#endif
 	oldpass = xstrdup (pw->pw_passwd);
 #endif				/* SU_ACCESS */
 
@@ -449,12 +442,10 @@ int main (int argc, char **argv)
 		exit (1);
 	}
 #ifndef USE_PAM
-#ifdef SHADOWPWD
 	spwd = NULL;
 	if (strcmp (pw->pw_passwd, SHADOW_PASSWD_STRING) == 0
 	    && (spwd = getspnam (name)))
 		pw->pw_passwd = spwd->sp_pwdp;
-#endif
 #endif				/* !USE_PAM */
 	pwent = *pw;
 
@@ -466,7 +457,7 @@ int main (int argc, char **argv)
 
 	/* The original Shadow 3.3.2 did this differently. Do it like BSD:
 	 *
-	 * - check for uid 0 instead of name "root" - there are systems with
+	 * - check for UID 0 instead of name "root" - there are systems with
 	 *   several root accounts under different names,
 	 *
 	 * - check the contents of /etc/group instead of the current group
@@ -511,6 +502,8 @@ int main (int argc, char **argv)
 	if (pwent.pw_shell[0] == '\0')
 		pwent.pw_shell = "/bin/sh";	/* XXX warning: const */
 
+	signal (SIGINT, SIG_IGN);
+	signal (SIGQUIT, SIG_IGN);
 #ifdef USE_PAM
 	ret = pam_authenticate (pamh, 0);
 	if (ret != PAM_SUCCESS) {
@@ -563,7 +556,6 @@ int main (int argc, char **argv)
 	 */
 
 	if (!amroot) {
-#ifdef	SHADOWPWD
 		if (!spwd)
 			spwd = pwd_to_spwd (&pwent);
 
@@ -572,7 +564,6 @@ int main (int argc, char **argv)
 				 "Expired account %s", name));
 			su_failure (tty);
 		}
-#endif
 	}
 
 	/*
@@ -593,6 +584,7 @@ int main (int argc, char **argv)
 #endif				/* !USE_PAM */
 
 	signal (SIGINT, SIG_DFL);
+#ifndef USE_PAM
 	cp = getdef_str ((pwent.pw_uid == 0) ? "ENV_SUPATH" : "ENV_PATH");
 
 	/* XXX very similar code duplicated in libmisc/setupenv.c */
@@ -604,10 +596,8 @@ int main (int argc, char **argv)
 		addenv ("PATH", cp);
 	}
 
-/* setup the environment for pam later on, else we run into auth problems */
-#ifndef USE_PAM
 	environ = newenvp;	/* make new environment active */
-#endif
+#endif				/* !USE_PAM */
 
 	if (getenv ("IFS"))	/* don't export user IFS ... */
 		addenv ("IFS= \t\n", NULL);	/* ... instead, set a safe IFS */
@@ -616,20 +606,16 @@ int main (int argc, char **argv)
 		pwent.pw_shell++;	/* skip the '*' */
 		subsystem (&pwent);	/* figure out what to execute */
 		endpwent ();
-#ifdef SHADOWPWD
 		endspent ();
-#endif
 		goto top;
 	}
 
 	sulog (tty, 1, oldname, name);	/* save SU information */
 	endpwent ();
-#ifdef SHADOWPWD
 	endspent ();
-#endif
 #ifdef USE_SYSLOG
 	if (getdef_bool ("SYSLOG_SU_ENAB"))
-		SYSLOG ((LOG_INFO, "+ %s %s-%s", tty,
+		SYSLOG ((LOG_INFO, "+ %s %s:%s", tty,
 			 oldname[0] ? oldname : "???", name[0] ? name : "???"));
 #endif
 
